==> dar_2.4.5.orig.tar.gz: dar-2.4.5/src/libdar/mem_ui.cpp <==
/*********************************************************************/
// dar - disk archive - a backup/restoration program
// Copyright (C) 2002-2052 Denis Corbin
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// to contact the author : http://dar.linux.free.fr/email.html
/*********************************************************************/
// $Id$
//
/*********************************************************************/

#include "../my_config.h"

#include "infinint.hpp"
// yep, strange thing to have to include the therorically less dependent header here.
// including "mem_ui.hpp" here, lead to cyclic dependancy of headers...  this points needs to be clarified

#include "mem_ui.hpp"

namespace libdar
{

    user_interaction & mem_ui::get_ui() const
    {
	if(ui == NULL)
	    throw SRC_BUG;

	return *(const_cast<mem_ui *>(this)->ui);
    }

    void mem_ui::detruire()
    {
	if(ui != NULL)
	{
	    delete ui;
	    ui = NULL;
	}
    }

    void mem_ui::copy_from(const mem_ui & ref)
    {
	if(ref.ui == NULL)
	    ui = NULL;
	else
	    set_ui(*(ref.ui));
    }

    static void dummy_call(char *x)
    {
        static char id[]="$Id$";
        dummy_call(id);
    }

    void mem_ui::set_ui(user_interaction & dialog)
    {
	ui = dialog.clone();
	if(ui == NULL)
	    throw Ememory("mem_ui::set_ui");
    }

} // end of namespace

==> dar-2.7.17.tar.gz: dar-2.7.17/src/libdar/mem_ui.cpp <==
/*********************************************************************/
// dar - disk archive - a backup/restoration program
// Copyright (C) 2002-2025 Denis Corbin
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//
// to contact the author, see the AUTHOR file
/*********************************************************************/

#include "../my_config.h"

#include "infinint.hpp"
// yep, strange thing to have to include the therorically less dependent header here.
// including "mem_ui.hpp" here, lead to cyclic dependancy of headers...  this points needs to be clarified

#include "mem_ui.hpp"
#include "shell_interaction.hpp"

using namespace std;

namespace libdar
{

    mem_ui::mem_ui(const std::shared_ptr<user_interaction> & dialog): ui(dialog)
    {
	try
	{
	    if(!ui)
		ui = make_shared<shell_interaction>(cerr, cerr, false);
	}
	catch(std::bad_alloc & e)
	{
	    throw Ememory("mem_ui::mem_ui");
	}
    }

} // end of namespace
